@@ -10,7 +10,7 @@ from hydenv import models
 
 BY_AREA = """
 area[boundary~"administrative"][name="{boundary_name}"];
-node(area)[{attribute}{value}];out;
+{obj}(area)[{attribute}{value}];out;
 """
 
 
@@ -38,10 +38,10 @@ class HydenvOSMExamples:
         # set the Overpass API
         self.api = Overpass(url=overpass_url)
 
-    def run(self, boundary, attribute, value=None, dry=False, save=None, quiet=True):
+    def run(self, geometry, boundary, attribute, value=None, dry=False, save=None, quiet=True):
         # first build the query
         value = '=%s' % value if value is not None else ''
-        query = BY_AREA.format(boundary_name=boundary, attribute=attribute, value=value)
+        query = BY_AREA.format(obj=geometry, boundary_name=boundary, attribute=attribute, value=value)
 
         # if dry run, do not reach out to the Overpass server
         if dry:
@@ -56,7 +56,10 @@ class HydenvOSMExamples:
             print('Connecting %s...' % self.api.url)
         try:
             result = self.api.query(query)
-            nodes = result.get_nodes()
+            if geometry == 'nodes' or geometry == 'node':
+                nodes = result.get_nodes()
+            else:
+                nodes = result.ways
         except Exception as e:
             print('The following error was caused during Overpass connection:\n%s' % str(e))
             return
@@ -67,12 +70,21 @@ class HydenvOSMExamples:
             bar = ProgressBar(max_value=len(nodes), redirect_stdout=True)
         
         for i, node in enumerate(nodes):
-            wkt = 'SRID=4326;POINT (%f %f)' % (float(node.lon), float(node.lat))
+            if geometry == 'nodes' or geometry == 'node':
+                wkt = 'SRID=4326;POINT (%f %f)' % (float(node.lon), float(node.lat))
+            else:
+                points = node.get_nodes(resolve_missing=True)
+                # check if a POLYGON or LINESTRING is needed
+                if points[0] == points[-1]:
+                    wkt = 'SRID=4326;POLYGON ((%s))' % ','.join(['%s %s ' % (p.lon, p.lat) for p in points])
+                else:
+                    wkt = 'SRID=4326;LINESTRING (%s)' % ','.join(['%s %s' % (p.lon, p.lat) for p in points])
+                    
             osm = models.OSMNode(
                 id=node.id, 
                 geom=wkt, 
                 name=node.tags.get('name'),
-                node_type=value
+                node_type=value if value is not None and value != '' else attribute
             )
             for k,v in node.tags.items():
                 osm.raw_tags.append(models.OSMTag(key=k, value=v))
